@@ -5,11 +5,12 @@ from .Logger import Logger
 class LogsManager(Base):
     """Manages all logs/loggers that belong to the script."""
 
-    new_logger_created = Event(Logger)
-
     def __init__(self, script, create_default_logs=True):
         Base.__init__(self)
 
+        # events
+        self.new_logger_created = Event(Logger)
+
         self.script = script
         self.session = self.script.session
         self.loggers: [Logger] = []
@@ -26,7 +27,8 @@ class LogsManager(Base):
             self.default_loggers[name] = self.new_logger(title=name.title())
 
     def new_logger(self, title: str) -> Logger:
-        logger = self.session.CLASSES['logger'](name=title)
+        # logger = self.session.CLASSES['logger'](name=title)
+        logger = Logger(name=title)
         self.loggers.append(logger)
         self.new_logger_created.emit(logger)
         return logger
